==> geeklog-1.7.0-jp-extended-1.1.zip: geeklog-1.7.0-jp-extended-1.1/plugins/calendar/language/czech.php <==
<?php

###############################################################################
# czech.php
# This is the czech language (ISO 8859-2) page for the Geeklog Calendar Plug-in!
#
# Copyright (C) 2007 Ondrej Rusek
# rusek@gybon.cz
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

# index.php
$LANG_CAL_1 = array(
    1 => 'Kalend udlost',
    2 => 'Bohuel. dn udlosti k zobrazen.',
    3 => 'Kdy',
    4 => 'Kde',
    5 => 'Popis',
    6 => 'Pidat udlost',
    7 => 'Blc se udlosti',
    8 => 'By adding this event to your calendar you can quickly view only the events you are interested in by clicking "My Calendar" from the User Functions area.',
    9 => 'Pidat do osobnho kalende.',
    10 => 'Odebrat z mho kalende',
    11 => 'Pidat udlost do osobnho kalende uivatele %s',
    12 => 'Udlost',
    13 => 'Zatek',
    14 => 'Konec',
    15 => 'Zpt na kalend',
    16 => 'Kalend',
    17 => 'Poten datum',
    18 => 'Koncov datum',
    19 => 'Poadavky kalende',
    20 => 'Titulek',
    21 => 'Poten datum',
    22 => 'URL',
    23 => 'Tvoje udlosti',
    24 => 'Udlosti webu',
    25 => 'dn blc se udlosti',
    26 => 'Poslat udlost',
    27 => "Odeslnm udlosti pro {$_CONF['site_name']} pidte vai udlost do hlavnho kalende. Po odesln bude udlost podrobena schvlen a pot bude publikovna v hlavnm kalendi.",
    28 => 'Titulek',
    29 => 'as konce',
    30 => 'as zatku',
    31 => 'Vechny udlosti dne',
    32 => 'Adresa 1',
    33 => 'Adresa 2',
    34 => 'Msto',
    35 => 'Stt',
    36 => 'PS',
    37 => 'Typ udlosti',
    38 => 'Editovat typy udlost',
    39 => 'Umstn',
    40 => 'Pidat udlost do',
    41 => 'Hlavn kalend',
    42 => 'Osobn kalend',
    43 => 'Odkaz',
    44 => 'HTML tagy nejsou povoleny',
    45 => 'Odeslat',
    46 => 'Udlosti v systmu',
    47 => 'Top Ten udlost',
    48 => 'Kliknut',
    49 => 'dn udlosti.',
    50 => 'Udlosti',
    51 => 'Vymazat'
);

$_LANG_CAL_SEARCH = array(
    'results' => 'Vsledky kalende',
    'title' => 'Titulek',
    'date_time' => 'Datum & as',
    'location' => 'Umstn',
    'description' => 'Popis'
);

###############################################################################
# calendar.php ($LANG30)

$LANG_CAL_2 = array(
    8 => 'Pidat osobn udlost',
    9 => '%s udlost',
    10 => 'Udlosti pro',
    11 => 'Hlavn kalend',
    12 => 'Mj kalend',
    25 => 'Zpt do ',
    26 => 'Cel den',
    27 => 'Tden',
    28 => 'Osobn kalend pro',
    29 => 'Veejn kalend',
    30 => 'vymazat udlost',
    31 => 'Pidat',
    32 => 'Udlost',
    33 => 'Datum',
    34 => 'as',
    35 => 'Rychle pidat',
    36 => 'Odeslat',
    37 => 'Bohuel, pouit osobnho kalende nen povoleno',
    38 => 'Osobn editor udlost',
    39 => 'Den',
    40 => 'Tden',
    41 => 'Msc',
    42 => 'Pidat hlavn udlost',
    43 => 'Poadavky udlost'
);

###############################################################################
# admin/plugins/calendar/index.php, formerly admin/event.php ($LANG22)

$LANG_CAL_ADMIN = array(
    1 => 'Editor udlost',
    2 => 'Chyba',
    3 => 'Post Mode',
    4 => 'URL udlosti',
    5 => 'Datum zatku',
    6 => 'Datum konce',
    7 => 'Umstn udlosti',
    8 => 'Popis udlosti',
    9 => '(vetn http://)',
    10 => 'Muste zadata datum/as, titulek a popis',
    11 => 'Sprvce kalende',
    12 => 'Pro zmnu nebo vymazn udlosti, kliknte na ikonu udlosti.  Pro vytvoen nov udlosti, kliknte na "Vytvoit novou". Kliknutm na ikonu kopie vytvote kopii udlosti.',
    13 => 'Autor',
    14 => 'Datum zatku',
    15 => 'Datum konce',
    16 => '',
    17 => "Pistupujete k udlosti, na kterou nemte dostaten prva. Tento pokus byl zalogovn. Prosm, <a href=\"{$_CONF['site_admin_url']}/plugins/calendar/index.php\">vrae ze zpt na administraci udlost</a>.",
    18 => '',
    19 => '',
    20 => 'uloit',
    21 => 'cancel',
    22 => 'vymazat',
    23 => 'Chybn datum zatku.',
    24 => 'Chybn datum konce.',
    25 => 'Koncov datum je ped datem zatku.',
    26 => 'Delete old entries',
    27 => 'These are the events that are older than ',
    28 => ' months. Please click on the trashcan Icon on the bottom to delete them, or select a different timespan:<br' . XHTML . '>Find all entries that are older than ',
    29 => ' months.',
    30 => 'Update List',
    31 => 'Are You sure you want to permanently delete ALL selected users?',
    32 => 'List all',
    33 => 'No events selected for deletion',
    34 => 'Event ID',
    35 => 'could not be deleted',
    36 => 'Sucessfully deleted'
);

$LANG_CAL_MESSAGE = array(
    'save' => 'Udlost byla spn uloena.',
    'delete' => 'Udlost byla spn vymazna.',
    'private' => 'Udlost byla uloena do vaeho osobnho kalende',
    'login' => 'Nemohu otevt v osobn kalend dokud se nepihlste',
    'removed' => 'Udlost byla odstranna z vaeho osobnho kalende',
    'noprivate' => 'Bohuel, osobn kalende tento server nepodporuje',
    'unauth' => 'Bohuel, nemte administrtorsk pstup. Tento v pokus byl zalogovn'
);

$PLG_calendar_MESSAGE4 = "Dkujeme za odesln udlosti pro {$_CONF['site_name']}.  Nyn oekv potvrzen.  Jakmile bude potvrzena, naleznete ji v <a href=\"{$_CONF['site_url']}/calendar/index.php\">kalendi</a>.";
$PLG_calendar_MESSAGE17 = 'Udlost byla spn uloena.';
$PLG_calendar_MESSAGE18 = 'Udlost byla spn vymazna.';
$PLG_calendar_MESSAGE24 = 'Udlost byla uloena do kalende.';
$PLG_calendar_MESSAGE26 = 'Udlost byla vymazna.';

// Messages for the plugin upgrade
$PLG_calendar_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_calendar_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['calendar'] = array(
    'label' => 'Calendar',
    'title' => 'Calendar Configuration'
);

$LANG_confignames['calendar'] = array(
    'calendarloginrequired' => 'Calendar Login Required?',
    'hidecalendarmenu' => 'Hide Calendar Menu Entry?',
    'personalcalendars' => 'Enable Personal Calendars?',
    'eventsubmission' => 'Enable Submission Queue?',
    'showupcomingevents' => 'Show upcoming Events?',
    'upcomingeventsrange' => 'Upcoming Events Range',
    'event_types' => 'Event Types',
    'hour_mode' => 'Hour Mode',
    'notification' => 'Notification Email?',
    'delete_event' => 'Delete Events with Owner?',
    'aftersave' => 'After Saving Event',
    'default_permissions' => 'Event Default Permissions'
);

$LANG_configsubgroups['calendar'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_fs['calendar'] = array(
    'fs_main' => 'General Calendar Settings',
    'fs_permissions' => 'Default Permissions'
);

// Note: entries 0, 1, 6, 9, 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['calendar'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    6 => array('12' => 12, '24' => 24),
    9 => array('Forward to Event' => 'item', 'Display Admin List' => 'list', 'Display Calendar' => 'plugin', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3)
);

?>

==> geeklog-1.8.2-jp-extended-1.0.zip: geeklog-1.8.2-jp-extended-1.0/plugins/calendar/language/czech.php <==
<?php

###############################################################################
# czech.php
# This is the czech language (ISO 8859-2) page for the Geeklog Calendar Plug-in!
#
# Copyright (C) 2007 Ondrej Rusek
# rusek@gybon.cz
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

# index.php
$LANG_CAL_1 = array(
    1 => 'Kalend udlost',
    2 => 'Bohuel. dn udlosti k zobrazen.',
    3 => 'Kdy',
    4 => 'Kde',
    5 => 'Popis',
    6 => 'Pidat udlost',
    7 => 'Blc se udlosti',
    8 => 'By adding this event to your calendar you can quickly view only the events you are interested in by clicking "My Calendar" from the User Functions area.',
    9 => 'Pidat do osobnho kalende.',
    10 => 'Odebrat z mho kalende',
    11 => 'Pidat udlost do osobnho kalende uivatele %s',
    12 => 'Udlost',
    13 => 'Zatek',
    14 => 'Konec',
    15 => 'Zpt na kalend',
    16 => 'Kalend',
    17 => 'Poten datum',
    18 => 'Koncov datum',
    19 => 'Poadavky kalende',
    20 => 'Titulek',
    21 => 'Poten datum',
    22 => 'URL',
    23 => 'Tvoje udlosti',
    24 => 'Udlosti webu',
    25 => 'dn blc se udlosti',
    26 => 'Poslat udlost',
    27 => "Odeslnm udlosti pro {$_CONF['site_name']} pidte vai udlost do hlavnho kalende. Po odesln bude udlost podrobena schvlen a pot bude publikovna v hlavnm kalendi.",
    28 => 'Titulek',
    29 => 'as konce',
    30 => 'as zatku',
    31 => 'Vechny udlosti dne',
    32 => 'Adresa 1',
    33 => 'Adresa 2',
    34 => 'Msto',
    35 => 'Stt',
    36 => 'PS',
    37 => 'Typ udlosti',
    38 => 'Editovat typy udlost',
    39 => 'Umstn',
    40 => 'Pidat udlost do',
    41 => 'Hlavn kalend',
    42 => 'Osobn kalend',
    43 => 'Odkaz',
    44 => 'HTML tagy nejsou povoleny',
    45 => 'Odeslat',
    46 => 'Udlosti v systmu',
    47 => 'Top Ten udlost',
    48 => 'Kliknut',
    49 => 'dn udlosti.',
    50 => 'Udlosti',
    51 => 'Vymazat',
    'autotag_desc_event' => '[event: id alternate title] - Displays a link to an Event Link from the Calendar using the Event Title as the title. An alternate title may be specified but is not required.'
);

$_LANG_CAL_SEARCH = array(
    'results' => 'Vsledky kalende',
    'title' => 'Titulek',
    'date_time' => 'Datum & as',
    'location' => 'Umstn',
    'description' => 'Popis'
);

###############################################################################
# calendar.php ($LANG30)

$LANG_CAL_2 = array(
    8 => 'Pidat osobn udlost',
    9 => '%s udlost',
    10 => 'Udlosti pro',
    11 => 'Hlavn kalend',
    12 => 'Mj kalend',
    25 => 'Zpt do ',
    26 => 'Cel den',
    27 => 'Tden',
    28 => 'Osobn kalend pro',
    29 => 'Veejn kalend',
    30 => 'vymazat udlost',
    31 => 'Pidat',
    32 => 'Udlost',
    33 => 'Datum',
    34 => 'as',
    35 => 'Rychle pidat',
    36 => 'Odeslat',
    37 => 'Bohuel, pouit osobnho kalende nen povoleno',
    38 => 'Osobn editor udlost',
    39 => 'Den',
    40 => 'Tden',
    41 => 'Msc',
    42 => 'Pidat hlavn udlost',
    43 => 'Poadavky udlost'
);

###############################################################################
# admin/plugins/calendar/index.php, formerly admin/event.php ($LANG22)

$LANG_CAL_ADMIN = array(
    1 => 'Editor udlost',
    2 => 'Chyba',
    3 => 'Post Mode',
    4 => 'URL udlosti',
    5 => 'Datum zatku',
    6 => 'Datum konce',
    7 => 'Umstn udlosti',
    8 => 'Popis udlosti',
    9 => '(vetn http://)',
    10 => 'Muste zadata datum/as, titulek a popis',
    11 => 'Sprvce kalende',
    12 => 'Pro zmnu nebo vymazn udlosti, kliknte na ikonu udlosti.  Pro vytvoen nov udlosti, kliknte na "Vytvoit novou". Kliknutm na ikonu kopie vytvote kopii udlosti.',
    13 => 'Autor',
    14 => 'Datum zatku',
    15 => 'Datum konce',
    16 => '',
    17 => "Pistupujete k udlosti, na kterou nemte dostaten prva. Tento pokus byl zalogovn. Prosm, <a href=\"{$_CONF['site_admin_url']}/plugins/calendar/index.php\">vrae ze zpt na administraci udlost</a>.",
    18 => '',
    19 => '',
    20 => 'uloit',
    21 => 'cancel',
    22 => 'vymazat',
    23 => 'Chybn datum zatku.',
    24 => 'Chybn datum konce.',
    25 => 'Koncov datum je ped datem zatku.',
    26 => 'Delete old entries',
    27 => 'These are the events that are older than ',
    28 => ' months. Please click on the trashcan Icon on the bottom to delete them, or select a different timespan:<br' . XHTML . '>Find all entries that are older than ',
    29 => ' months.',
    30 => 'Update List',
    31 => 'Are You sure you want to permanently delete ALL selected users?',
    32 => 'List all',
    33 => 'No events selected for deletion',
    34 => 'Event ID',
    35 => 'could not be deleted',
    36 => 'Sucessfully deleted'
);

$LANG_CAL_MESSAGE = array(
    'save' => 'Udlost byla spn uloena.',
    'delete' => 'Udlost byla spn vymazna.',
    'private' => 'Udlost byla uloena do vaeho osobnho kalende',
    'login' => 'Nemohu otevt v osobn kalend dokud se nepihlste',
    'removed' => 'Udlost byla odstranna z vaeho osobnho kalende',
    'noprivate' => 'Bohuel, osobn kalende tento server nepodporuje',
    'unauth' => 'Bohuel, nemte administrtorsk pstup. Tento v pokus byl zalogovn'
);

$PLG_calendar_MESSAGE4 = "Dkujeme za odesln udlosti pro {$_CONF['site_name']}.  Nyn oekv potvrzen.  Jakmile bude potvrzena, naleznete ji v <a href=\"{$_CONF['site_url']}/calendar/index.php\">kalendi</a>.";
$PLG_calendar_MESSAGE17 = 'Udlost byla spn uloena.';
$PLG_calendar_MESSAGE18 = 'Udlost byla spn vymazna.';
$PLG_calendar_MESSAGE24 = 'Udlost byla uloena do kalende.';
$PLG_calendar_MESSAGE26 = 'Udlost byla vymazna.';

// Messages for the plugin upgrade
$PLG_calendar_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_calendar_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['calendar'] = array(
    'label' => 'Calendar',
    'title' => 'Calendar Configuration'
);

$LANG_confignames['calendar'] = array(
    'calendarloginrequired' => 'Calendar Login Required?',
    'hidecalendarmenu' => 'Hide Calendar Menu Entry?',
    'personalcalendars' => 'Enable Personal Calendars?',
    'eventsubmission' => 'Enable Submission Queue?',
    'showupcomingevents' => 'Show upcoming Events?',
    'upcomingeventsrange' => 'Upcoming Events Range',
    'event_types' => 'Event Types',
    'hour_mode' => 'Hour Mode',
    'notification' => 'Notification Email?',
    'delete_event' => 'Delete Events with Owner?',
    'aftersave' => 'After Saving Event',
    'default_permissions' => 'Event Default Permissions',
    'autotag_permissions_event' => '[event: ] Permissions'
);

$LANG_configsubgroups['calendar'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_tab['calendar'] = array(
    'tab_main' => 'General Calendar Settings',
    'tab_permissions' => 'Default Permissions',
    'tab_autotag_permissions' => 'Autotag Usage Permissions'
);

$LANG_fs['calendar'] = array(
    'fs_main' => 'General Calendar Settings',
    'fs_permissions' => 'Default Permissions',
    'fs_autotag_permissions' => 'Autotag Usage Permissions'
);

// Note: entries 0, 1, 6, 9, 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['calendar'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    6 => array('12' => 12, '24' => 24),
    9 => array('Forward to Event' => 'item', 'Display Admin List' => 'list', 'Display Calendar' => 'plugin', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3),
    13 => array('No access' => 0, 'Use' => 2)
);

?>
